@@ -7,6 +7,12 @@ from sys import stderr
 from math import log, inf
 from functools import partial
 
+try:
+    from ._version import version
+    __version__ = version
+except ImportError:
+    pass
+
 
 HERE = os.path.abspath(os.path.dirname(__file__))
 
@@ -122,7 +128,7 @@ def _iter_metadata(s2rl_file):
         if s2rl_file.endswith(".tsv"):
             dialect = "excel-tab"
         for samp in csv.DictReader(fh, dialect=dialect):
-            yield samp
+            yield {k.lower(): v for k, v in samp.items()}
 
 
 def make_runlib2samp(s2rl_file):
